pub enum Cast {
Sample,
Fourier,
IFourier,
Stft {
window: usize,
hop: usize,
},
Istft,
}Variants
Implementations
Sourceimpl Cast
impl Cast
pub const NAMES: [&'static str; 5]
pub fn from_name(name: &str, named: &[(&'_ str, f64)]) -> Option<Cast>
pub fn name(self) -> &'static str
Sourcepub fn check_arguments(self) -> Result<(), Mismatch>
pub fn check_arguments(self) -> Result<(), Mismatch>
A window and a hop belong to the cast, so they are checked where the call is written.
pub fn resolve(self, args: &[Ty]) -> Result<Ty, Mismatch>