pub enum PrunePolicy {
Oldest,
Forks,
}Variants
Oldest
Every entry the newest render neither stored nor read.
Forks
Every entry whose node fewer than two nodes read.
Implementations
Sourceimpl PrunePolicy
impl PrunePolicy