pub async fn render_over<B: Backend>(
graph: &Graph,
target: &str,
config: RenderConfig,
tier: &Tier<B>,
) -> Result<Render, EngineError>Expand description
target over tier, from the root down, in a session of its own.
pub async fn render_over<B: Backend>(
graph: &Graph,
target: &str,
config: RenderConfig,
tier: &Tier<B>,
) -> Result<Render, EngineError>target over tier, from the root down, in a session of its own.