pub fn sketch_atom(a: &SpectralAtom) -> StringExpand description
One atom as the six factors it is present in, which is what atoms answers with.
pub fn sketch_atom(a: &SpectralAtom) -> StringOne atom as the six factors it is present in, which is what atoms answers with.