pub struct Buffer {
pub rate: u32,
pub start: i64,
pub planes: Vec<Vec<f64>>,
}Fields
rate: u32start: i64The grid sample the first of these stands at; sample 0 is t = 0.
planes: Vec<Vec<f64>>Implementations
Sourceimpl Buffer
impl Buffer
pub fn silence(rate: u32, width: usize, len: usize) -> Buffer
pub fn empty(rate: u32, width: usize, capacity: usize, start: i64) -> Buffer
pub fn mono(rate: u32, samples: Vec<f64>) -> Buffer
pub fn of_planes(rate: u32, planes: Vec<Vec<f64>>) -> Buffer
pub fn width(&self) -> usize
pub fn plane(&self, c: usize) -> &[f64]
pub fn plane_mut(&mut self, c: usize) -> &mut [f64]
pub fn slices(&self) -> Vec<&[f64]>
pub fn len(&self) -> usize
pub fn is_empty(&self) -> bool
pub fn at(&self, c: usize, i: usize) -> f64
pub fn origin_secs(&self) -> f64
pub fn end(&self) -> i64
pub fn extent(&self) -> Extent
pub fn capacity(&self) -> usize
pub fn push(&mut self, c: usize, value: f64)
pub fn forget_before(&mut self, from: i64)
Sourcepub fn within(&self, support: Extent) -> SampleView<'_>
pub fn within(&self, support: Extent) -> SampleView<'_>
A node zero outside support.
Sourcepub fn over(&self, over: Extent, support: Extent) -> Buffer
pub fn over(&self, over: Extent, support: Extent) -> Buffer
These samples over over, a node that is zero outside support.
pub fn plane_slice(&self, c: usize, range: Range<usize>) -> Cow<'_, [f64]>