pub struct C64 {
pub re: f64,
pub im: f64,
}Fields
re: f64im: f64Implementations
Sourceimpl C64
impl C64
pub const ZERO: C64
pub const ONE: C64
pub const I: C64
pub fn new(re: f64, im: f64) -> C64
pub fn real(re: f64) -> C64
pub fn bits(self) -> (u64, u64)
pub fn is_finite(self) -> bool
pub fn is_zero(self) -> bool
pub fn is_real(self) -> bool
pub fn conj(self) -> C64
pub fn norm_sqr(self) -> f64
pub fn abs(self) -> f64
Sourcepub fn inv(self) -> C64
pub fn inv(self) -> C64
A component alone on its axis inverts by one division, correctly rounded; only a value off both axes takes the conjugate over the squared norm.
pub fn exp(self) -> C64
pub fn powi(self, n: u32) -> C64
pub fn scale(self, k: f64) -> C64
pub fn over(self, k: f64) -> C64