pub struct Stored {
pub key: Hash,
pub segments: Vec<Buffer>,
pub label: Label,
pub width: u8,
pub codomain: Codomain,
pub rate: Option<u32>,
pub grid: Grid,
pub support: Extent,
pub priced: u128,
pub moved: f64,
pub readable: bool,
}Expand description
A node’s samples, and what a render needs to read them in place of typing the node.
Fields
key: Hashsegments: Vec<Buffer>label: Labelwidth: u8codomain: Codomainrate: Option<u32>grid: Gridsupport: Extentpriced: u128Flops it and every value under it cost when computed.
moved: f64The most seconds a read under it moved to land on a sample.
readable: boolA reader may take these samples in place of computing the node.