Through

Trait Through 

pub trait Through {
    // Required methods
    fn lookup(&self, key: Hash) -> impl Future<Output = Option<Stored>>;
    fn read(
        &self,
        stored: &Stored,
        over: Extent,
    ) -> impl Future<Output = Option<Vec<Buffer>>>;
    fn epoch(&self) -> u64;
}
A store, or nothing, that a render looks a node up in and reads its samples from.

Required Methods

fn lookup(&self, key: Hash) -> impl Future<Output = Option<Stored>>

fn read( &self, stored: &Stored, over: Extent, ) -> impl Future<Output = Option<Vec<Buffer>>>

Whole chunks holding over; None where they are gone or corrupt.

fn epoch(&self) -> u64

Moves on whenever this holder stages or commits.

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors