pub fn ends(
graph: &Graph,
roots: &[String],
config: &RenderConfig,
) -> Result<Vec<Option<i64>>, EngineError>Expand description
The sample each of roots read bare would end at, None where its support never ends.
pub fn ends(
graph: &Graph,
roots: &[String],
config: &RenderConfig,
) -> Result<Vec<Option<i64>>, EngineError>The sample each of roots read bare would end at, None where its support never ends.