pub fn ends(
graph: &Graph,
roots: &[String],
config: &RenderConfig,
) -> Result<Vec<Option<i64>>, EngineError>Expand description
The sample each of roots read bare would end at, None where its support, pruning
included, never ends and such a render refuses for it. Typed together, and no sample.