Buffer

Struct Buffer 

pub struct Buffer {
    pub rate: u32,
    pub start: i64,
    pub width: usize,
    pub planes: Vec<Vec<f64>>,
}

Fields

rate: u32start: i64

The grid sample the first of these stands at; sample 0 is t = 0.

width: usizeplanes: Vec<Vec<f64>>

Implementations

Source

impl Buffer

pub fn silence(rate: u32, width: usize, len: usize) -> Buffer

pub fn mono(rate: u32, samples: Vec<f64>) -> Buffer

pub fn of_planes(rate: u32, planes: Vec<Vec<f64>>) -> Buffer

pub fn plane(&self, c: usize) -> &[f64]

pub fn plane_mut(&mut self, c: usize) -> &mut [f64]

pub fn slices(&self) -> Vec<&[f64]>

pub fn len(&self) -> usize

pub fn is_empty(&self) -> bool

pub fn at(&self, c: usize, i: usize) -> f64

pub fn origin_secs(&self) -> f64

pub fn extent(&self) -> Extent

The grid samples this holds.

pub fn over(&self, over: Extent, support: Extent) -> Buffer

These samples over over, a node that is zero outside support.

pub fn window(&self, c: usize, range: Range<usize>) -> Cow<'_, [f64]>

pub fn as_f32(&self, c: usize) -> Vec<f32>

The only narrowing in the crate: a WAV file and the wasm boundary are both f32.