pub trait Through {
// Required methods
fn lookup(&self, key: Hash) -> impl Future<Output = Option<Stored>>;
fn read(
&self,
stored: &Stored,
over: Extent,
) -> impl Future<Output = Option<Vec<Buffer>>>;
fn epoch(&self) -> u64;
}Expand description
A store, or nothing, that a render looks a node up in and reads its samples from.
Required Methods
fn lookup(&self, key: Hash) -> impl Future<Output = Option<Stored>>
Dyn Compatibility
This trait is not dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".